const {
  EmbedBuilder,
  ActionRowBuilder,
  StringSelectMenuBuilder,
  ButtonBuilder,
  ButtonStyle,
  PermissionFlagsBits,
  ComponentType,
  ModalBuilder,
  TextInputStyle,
  TextInputBuilder,
  ChannelSelectMenuBuilder
} = require("discord.js")
const { toRgb, ms } = require("./misc") 
const { SimplyError } = require("./error") 
Object.defineProperty(exports, "__esModule", { value: true });

// ------------------------------
// ------ F U N C T I O N -------
// ------------------------------

/**
 * Lets you create embeds with **an interactive builder**
 * @param msgOrInt
 * @param options
 * @link `Documentation:` https://simplyd.js.org/docs/general/embedCreator
 * @example simplydjs.embedCreate(interaction)
 */

 async function embedCreator(msgOrInt, options = { strict: false }) {
  return new Promise(async resolve => {
    try {
      const done = new ButtonBuilder()
        .setLabel("Finish")
        .setStyle(ButtonStyle.Primary)
        .setCustomId("setDone")

      const reject = new ButtonBuilder()
        .setLabel("Cancel")
        .setStyle(ButtonStyle.Danger)
        .setCustomId("setDelete")

      const menuOptions = [
        {
          label: "Message",
          description: "Message that is outside of the embed",
          value: "setMessage",
          emoji: "💬"
        },
        {
          label: "Author",
          description: "Set an author in the embed",
          value: "setAuthor"
        },
        {
          label: "Title",
          description: "Set a title in the embed",
          value: "setTitle"
        },
        {
          label: "URL",
          description: "Set an URL for the Title in the embed",
          value: "setURL"
        },
        {
          label: "Description",
          description: "Set a description in the embed",
          value: "setDescription"
        },
        {
          label: "Color",
          description: "Pick a color of the embed",
          value: "setColor"
        },

        {
          label: "Image",
          description: "Set an image for the embed",
          value: "setImage"
        },
        {
          label: "Thumbnail",
          description: "Set a thumbnail image in the embed",
          value: "setThumbnail"
        },
        {
          label: "Field",
          description: "Add a field to the embed",
          value: "addField"
        },
        {
          label: "Footer",
          description: "Set a footer in the embed",
          value: "setFooter"
        },
        {
          label: "Timestamp",
          description: "Turn on the Timestamp of the embed",
          value: "setTimestamp"
        }
      ]

      if (!options.embed) {
        options.embed = {
          color: toRgb("#406DBC")
        }
      }

      const select = new StringSelectMenuBuilder()
        .setMaxValues(1)
        .setCustomId("embed-creator")
        .setPlaceholder("Embed Creator")
        .addOptions(menuOptions)

      const row = new ActionRowBuilder().addComponents([done, reject])

      const selectRow = new ActionRowBuilder().addComponents([select])

      const embed = new EmbedBuilder()
        .setTitle(options.embed?.title || "Embed Generator")
        .setDescription(
          options.embed?.description ||
            "Select any option from the Select Menu in this message to create a custom embed for you."
        )
        .setColor(options.embed?.color || toRgb("#406DBC"))
        .setFooter(
          options.embed?.footer
            ? options.embed?.footer
            : {
                text: "Razen | Embed Generator",
                iconURL:
                  "https://images-ext-1.discordapp.net/external/O6pyaHXflIsI5rRJ6SOqsY8x5G4fh51hJy48KTqa1ME/https/cdn.discordapp.com/icons/1093638814171418706/a_027b54ff405ef991b185ead7927b2c7e.gif"
              }
        )

      if (options?.embed?.author) embed.setAuthor(options.embed?.author)
      if (options?.embed?.image) embed.setImage(options.embed?.image)
      if (options?.embed?.thumbnail)
        embed.setThumbnail(options.embed?.thumbnail)
      if (options?.embed?.timestamp)
        embed.setTimestamp(options.embed?.timestamp)
      if (options?.embed?.title) embed.setTitle(options.embed?.title)
      if (options?.embed?.url) embed.setURL(options.embed?.url)
      if (options?.embed?.fields) embed.setFields(options.embed?.fields)

      let interaction

      if (msgOrInt.commandId) {
        interaction = msgOrInt

        if (!interaction.deferred)
          await interaction.deferReply({ fetchReply: true })
      }

      let msg

      const extInteraction = msgOrInt
      const extMessage = msgOrInt

      if (interaction) {
        msg = await extInteraction.followUp({
          embeds: [embed],
          components: [selectRow, row],
          fetchReply: true
        })
      } else if (!interaction) {
        msg = await extMessage.reply({
          embeds: [embed],
          components: [selectRow, row]
        })
      }

      const creator = new EmbedBuilder()
        .setFooter(
          options.embed?.footer
            ? options.embed?.footer
            : {
                text: "Razen | Embed Generator",
                iconURL:
                  "https://images-ext-1.discordapp.net/external/O6pyaHXflIsI5rRJ6SOqsY8x5G4fh51hJy48KTqa1ME/https/cdn.discordapp.com/icons/1093638814171418706/a_027b54ff405ef991b185ead7927b2c7e.gif"
              }
        )
        .setColor(toRgb("#2F3136"))

      msgOrInt.channel
        .send({ content: "** **", embeds: [creator] })
        .then(async preview => {
          const filter = m => {
            if (m.user.id === msgOrInt.member.user.id) return true
            m.reply({
              content: `Only <@!${msgOrInt.member.user.id}> can use these buttons!`,
              ephemeral: true
            })
            return false
          }

          const messageFilter = m => msgOrInt.member.user.id === m.author.id

          const buttonFilter = m => {
            if (m.user.id === msgOrInt.member.user.id) return true
            m.reply({
              content: `Only <@!${msgOrInt.member.user.id}> can use these buttons!`,
              ephemeral: true
            })
            return false
          }

          const collector = msg.createMessageComponentCollector({
            filter: filter,
            componentType: ComponentType.StringSelect,
            idle: ms("50m")
          })

          const buttonCltr = msg.createMessageComponentCollector({
            filter: filter,
            componentType: ComponentType.Button,
            idle: ms("60m")
          })

          buttonCltr.on("collect", async button => {
            if (button.customId === "setDelete") {
              await button.reply({
                content: "Deleting your request.",
                ephemeral: true
              })

              preview.delete().catch(() => {})
              msg.delete().catch(() => {})
            } else if (button.customId === "setDone") {
              if (
                msgOrInt.member.permissions.has(
                  PermissionFlagsBits.Administrator
                )
              ) {
                const userSelect = new ChannelSelectMenuBuilder()
                  .setCustomId("embedChannel")
                  .setPlaceholder("Select the channel.")
                  .setMinValues(1)
                  .setMaxValues(1)

                const row1 = new ActionRowBuilder().addComponents(userSelect)

                const msg = await button.reply({
                  content: "Where should i send the embed?",
                  components: [row1],
                  ephemeral: true
                })
                const msgCollector = await msg.createMessageComponentCollector({
                    filter: m => msgOrInt.member.user.id === m.user.id,
                    time: ms("5m"),
                    componentType: ComponentType.ChannelSelect
                  })

                  msgCollector.on("collect", async i => {
                    const channel = i.values[0]

                    if (channel) {
                      await button.editReply({
                        content: `***🟢 Selected the channel <#${channel}>, by ${i.user}***`
                      })
                      const ch = button.guild.channels.cache.get(channel)
                      ch.send({
                        content: preview.content,
                        embeds: [preview.embeds[0]]
                      })
                      preview.delete().catch(() => {})
                      msg.delete().catch(() => {})
                      button.message.delete().catch(() => {})
  
                      resolve(preview.embeds[0].toJSON())
                    }
                  })
                // const msgCollector = button.channel.createMessageCollector({
                //   filter: messageFilter,
                //   time: ms("1m"),
                //   max: 1
                // })

                // msgCollector.on("collect", async m => {
                //   if (m.mentions.channels.first()) {
                //     const ch = m.mentions.channels.first()
                //     await button.editReply({ content: "Done 👍" })

                //     ch.send({
                //       content: preview.content,
                //       embeds: [preview.embeds[0]]
                //     })
                //     preview.delete().catch(() => {})
                //     msg.delete().catch(() => {})
                //     m.delete().catch(() => {})

                //     resolve(preview.embeds[0].toJSON())
                //   }
                // })
              } else if (
                !msgOrInt.member.permissions.has(
                  PermissionFlagsBits.Administrator
                )
              ) {
                await button.reply({ content: "Done 👍", ephemeral: true })

                msgOrInt.channel.send({
                  content: preview.content,
                  embeds: [preview.embeds[0]]
                })
                preview.delete().catch(() => {})
                msg.delete().catch(() => {})

                resolve(preview.embeds[0].toJSON())
              }
            }
          })

          collector.on("collect", async menu => {
            if (menu.values[0] === "setTimestamp") {
              const btn = new ButtonBuilder()
                .setLabel("Yes")
                .setCustomId("timestamp-yes")
                .setStyle(ButtonStyle.Primary)
                .setEmoji("🟢")

              const btn2 = new ButtonBuilder()
                .setLabel("No")
                .setCustomId("timestamp-no")
                .setStyle(ButtonStyle.Danger)
                .setEmoji("🔴")

              await menu.reply({
                content: "*** 🟢 Do you wish to have a timestamp on the embed?***",
                ephemeral: true,
                components: [new ActionRowBuilder().addComponents([btn, btn2])]
              })

              const buttonCollector = menu.channel.createMessageComponentCollector(
                {
                  componentType: ComponentType.Button,
                  filter: buttonFilter,
                  idle: ms("3m")
                }
              )

              buttonCollector.on("collect", async button => {
                if (button.customId === "timestamp-yes") {
                  await menu.editReply({
                    components: [],
                    content: "***🟢 Successfuly enabled the timestamp on your embed.***"
                  })

                  preview
                    .edit({
                      content: preview.content,
                      embeds: [
                        EmbedBuilder.from(preview.embeds[0]).setTimestamp(
                          new Date()
                        )
                      ]
                    })
                    .catch(() => {})
                }

                if (button.customId === "timestamp-no") {
                  await menu.editReply({
                    components: [],
                    content: "***🟢 Successfuly disabled the timestamp on your embed.***"
                  })

                  preview
                    .edit({
                      content: preview.content,
                      embeds: [
                        EmbedBuilder.from(preview.embeds[0]).setTimestamp(null)
                      ]
                    })
                    .catch(() => {})
                }
              })
            } else if (menu.values[0] === "setAuthor") {
           

              const row = new ActionRowBuilder().addComponents(
                new ButtonBuilder().setLabel("Author text").setCustomId("author-text").setStyle(ButtonStyle.Primary),
                new ButtonBuilder().setLabel("Author icon").setCustomId("author-icon").setStyle(ButtonStyle.Primary),
                new ButtonBuilder().setLabel("Author url").setCustomId("author-url").setStyle(ButtonStyle.Primary)
              )

              await menu.reply({
                content: 'Select one from the "Author" options',
                ephemeral: true,
                components: [
                  row
                ]
              })

              const menuCollector = menu.channel.createMessageComponentCollector(
                {
                  componentType: ComponentType.Button,
                  filter: filter,
                  idle: ms("20m")
                }
              )

              menuCollector.on("collect", async btn => {

                if (btn.customId === "author-text") {
                  const authorText = await btn.reply({ content: "Send me the Author text", ephemeral: true , components: []})
                 

                  const messageCollect = await btn.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("20m"),
                    max: 1
                  })
                  messageCollect.on("collect", async m => {
                
                    const author = m.content
                    
                
                    await authorText.edit({
                      content: `***🟢 Successfuly set the author text on your embed.***`,
                      ephemeral: true
                    })

                    preview
                      .edit({
                        content: preview.content,
                        embeds: [
                          EmbedBuilder.from(preview.embeds[0]).setAuthor({
                            name: author,
                            iconURL: preview.embeds[0].author?.iconURL
                              ? preview.embeds[0].author?.iconURL
                              : null,
                            url: preview.embeds[0].author?.url
                              ? preview.embeds[0].author?.url
                              : null
                          })
                        ]
                      })
                      .catch(() => {})
                
                      m.delete().catch(() => {})
                      authorText.delete().catch(() => {})
                  })
                     
                    
                  }
                

                if (btn.customId === "author-icon") {
                 const authorIcon = await btn.reply({
                    content: "Send me the Author icon (Attachment/Image URL)",
                    ephemeral: true,
                    components: []
                  })

                  const messageCollect = btn.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("20m"),
                    max: 1
                  })

                  messageCollect.on("collect", async m => {
                    const isthumb =
                      m.content.match(
                        /(http[s]*:\/\/)([a-z\-_0-9\/.]+)\.([a-z.]{2,3})\/([a-z0-9\-_\/._~:?#\[\]@!$&'()*+,;=%]*)([a-z0-9]+\.)(jpg|jpeg|png)/i
                      ) != null ||
                      m.attachments.first()?.url ||
                      null
                    if (!isthumb)
                      btn.followUp({
                        content:
                          "\`🔴\` ・ I'm sorry but your content is not a valid image URL or an image attachment.",
                        ephemeral: true
                      })

                    
                    m.delete().catch(() => {})
                    authorIcon.delete().catch(() => {})
                    preview
                      .edit({
                        content: preview.content,
                        embeds: [
                          EmbedBuilder.from(preview.embeds[0]).setAuthor({
                            name: preview.embeds[0].author?.name
                              ? preview.embeds[0].author?.name
                              : null,
                            iconURL:
                              m.content || m.attachments.first()?.url || null,
                            url: preview.embeds[0].author?.url
                              ? preview.embeds[0].author?.url
                              : null
                          })
                        ]
                      })
                      .catch(() => {})
                  })
                }

                if (btn.customId === "author-url") {
                  const authorText = await btn.reply({ content: "Send me the Author text\n- *Send `Cancel` if you want to cancel*", ephemeral: true , components: []})
                 

                  const messageCollect =  await btn.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("20m"),
                    max: 1
                  })
                  messageCollect.on("collect", async m => {
                
                    const link = m.content
                    
                
                   

                 

                    if (link.toLowerCase() === "cancel") {
                      await btn.reply({
                        content: `\`🔐\` ・ The operation has been cancelled.`,
                        ephemeral: true
                      })
                    } else if (!link.startsWith("http")) {
                      await btn.reply({
                        content:
                          "\`🔴\` ・ An URL should start with `http` or `https`.",
                        ephemeral: true
                      })
                      return
                    } else {
                      // await btn.reply({
                      //   content: `***🟢 Successfuly set the URL on your embed.***`,
                      //   ephemeral: true
                      // })
                      await authorText.edit({
                        content: `***🟢 Successfuly set the author url on your embed.***`,
                        ephemeral: true
                      })

                      preview
                        .edit({
                          content: preview.content,
                          embeds: [
                            EmbedBuilder.from(preview.embeds[0]).setAuthor({
                              name: preview.embeds[0].author?.name
                                ? preview.embeds[0].author?.name
                                : null,
                              iconURL: preview.embeds[0].author?.iconURL
                                ? preview.embeds[0].author?.iconURL
                                : null,
                              url: link || null
                            })
                          ]
                        })
                        .catch(() => {})
                        m.delete().catch(() => {})
                        authorText.delete().catch(() => {})
                    }
                  })
                }
              })
            } else if (menu.values[0] === "setMessage") {
              const authorText = await menu.reply({ content: "Send me the message that will be displayed above the embed\n> - *Send \`Cancel\` to cancle this operation.*", ephemeral: true , components: []})
                 

                  const messageCollect = await menu.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("50m"),
                    max: 1
                  })
                  messageCollect.on("collect", async m => {
                
                    const message = m.content
                    
                
                    await authorText.edit({
                      content: `***🟢 Successfuly set the message.***`,
                      ephemeral: true
                    })
                

                if (message.toLowerCase() === "cancel") {
                  await authorText.edit({
                    content: `You have cancelled.`,
                    ephemeral: true
                  })
                } else {
                  // await submitted.reply({
                  //   content: `***🟢 Successfuly set the message.***`,
                  //   ephemeral: true
                  // })

                  preview
                    .edit({ content: message, embeds: [preview.embeds[0]] })
                    .catch(() => {})
                    m.delete().catch(() => {})
                    authorText.delete().catch(() => {})
                }
              })
              
            } else if (menu.values[0] === "setThumbnail") {
              const embedThumbnail = await menu.reply({
                content:
                  "Send the image url or attachment that will be displayed on the embed thumbnail\n> - *The thumbnail is the small image at the top of the embed, not the author icon.*",
                ephemeral: true
              })

              const messageCollect = menu.channel.createMessageCollector({
                filter: messageFilter,
                time: ms("30m"),
                max: 1
              })

              messageCollect.on("collect", async m => {
                const isthumb =
                  m.content.match(
                    /(http[s]*:\/\/)([a-z\-_0-9\/.]+)\.([a-z.]{2,3})\/([a-z0-9\-_\/._~:?#\[\]@!$&'()*+,;=%]*)([a-z0-9]+\.)(jpg|jpeg|png)/i
                  ) != null ||
                  m.attachments.first()?.url ||
                  null
                if (!isthumb) {
                  select.followUp({
                    content:
                      "\`🔴\` ・ This is not a valid image URL or an image attachment.",
                    ephemeral: true
                  })
                  return
                }

                embedThumbnail.delete().catch(() => {})
                m.delete().catch(() => {})

                preview
                  .edit({
                    content: preview.content,
                    embeds: [
                      EmbedBuilder.from(preview.embeds[0]).setThumbnail(
                        m.content || m.attachments.first()?.url || null
                      )
                    ]
                  })
                  .catch(() => {})
              })
            } else if (menu.values[0] === "setColor") {
              const authorText = await menu.reply({ content: "Send me the embed HEX Color\n> - *Send \`Cancel\` to cancle this operation.*", ephemeral: true , components: []})
                 

              const messageCollect = await menu.channel.createMessageCollector({
                filter: messageFilter,
                time: ms("10m"),
                max: 1
              })
              messageCollect.on("collect", async m => {
            
                const hex = m.content
                
            
                
            

           

                if (hex.toLowerCase() === "cancel") {
                  await authorText.edit({
                    content: `You have cancelled.`,
                    ephemeral: true
                  })
                } else if (/^#[0-9A-F]{6}$/i.test(hex)) {
                  preview
                    .edit({
                      content: preview.content,
                      embeds: [
                        EmbedBuilder.from(preview.embeds[0]).setColor(
                          toRgb(hex)
                        )
                      ]
                    })
                    .then(async () => {
                      await authorText.edit({
                        content: `***🟢 Successfuly set the embed color.***`,
                        ephemeral: true
                      })
                      authorText.delete().catch(() => {})
                      m.delete().catch(() => {})
                      
                    })
                    .catch(async () => {
                      await authorText.edit({
                        content: `\`🔴\` ・ Please provide a valid hex code with \`#\` (Example: #406DBC)`,
                        ephemeral: true
                      })
                    })
                } else
                  await authorText.edit({
                    content: `\`🔴\` ・ Please provide a valid hex code with \`#\` (Example: #406DBC)`,
                    ephemeral: true
                  })
                })
            } else if (menu.values[0] === "setURL") {
              
              const authorText = await menu.reply({ content: "Send me the link that will be the embed URL (hypherlink)\n> - *Send \`Cancel\` to cancle this operation.*", ephemeral: true , components: []})
                 

                  const messageCollect = await menu.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("10m"),
                    max: 1
                  })
                  messageCollect.on("collect", async m => {
                
                    const url = m.content
                    
                
                    
                

              

                if (url.toLowerCase() === "cancel") {
                  await authorText.edit({
                    content: `You have cancelled.`,
                    ephemeral: true
                  })
                } else if (!url.startsWith("http")) {
                  await authorText.edit({
                    content: `\`🔴\` ・ A url should start with "http" or "https".`,
                    ephemeral: true
                  })
                } else {
                  await authorText.edit({
                    content: `***🟢 Successfuly set the Embed URL.***`,
                    ephemeral: true
                  })

                  preview
                    .edit({
                      content: preview.content,
                      embeds: [EmbedBuilder.from(preview.embeds[0]).setURL(url)]
                    })
                    .catch(() => {})
                    authorText.delete().catch(() => {})
                    m.delete().catch(() => {})
                
              }
            })
            } else if (menu.values[0] == "addField") {
              
              const row = new ActionRowBuilder().addComponents(
                new ButtonBuilder().setLabel("Add a field").setCustomId("add-field").setStyle(ButtonStyle.Primary),
              )

              await menu.reply({
                content: '***🔐 Click below to add a field.***',
                ephemeral: true,
                components: [
                  row
                ]
              })

              const menuCollector = menu.channel.createMessageComponentCollector(
                {
                  componentType: ComponentType.Button,
                  filter: filter,
                  idle: ms("5m")
                }
              )

              menuCollector.on("collect", async btn => {

                if (btn.customId === "add-field") {
                  const fieldName = await btn.reply({ content: "Send me the field name.", ephemeral: true , components: []})
                 

                  const messageCollect = await btn.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("20m"),
                    max: 1
                  })
                  messageCollect.on("collect", async m => {
                var fieldN = m.content


                   const fieldValue = await fieldName.edit({ content: "Send me the field value (description).", ephemeral: true , components: []})
                 
m.delete().catch(() => {})
                  const messageCollect = await btn.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("10m"),
                    max: 1
                  })
                  messageCollect.on("collect", async x => {
                var fieldV = x.content

                
                    
                  await fieldName.edit({
                    content: `***🟢 Successfuly added the field in embed.***`,
                    ephemeral: true
                  })

                  preview
                    .edit({
                      content: preview.content,
                      embeds: [
                        EmbedBuilder.from(preview.embeds[0]).addFields({
                          name: fieldN,
                          value: fieldV
                        })
                      ]
                    })
                    .catch(() => {})
                    x.delete().catch(() => {})
                    m.delete().catch(() => {})
fieldValue.delete().catch(() => {})
fieldName.delete().catch(() => {})
                
              
              })
              })
            
            }
          })
            } else if (menu.values[0] === "setImage") {
              const footerImage = await menu.reply({
                content: "Send me the image url/image attachment.",
                ephemeral: true
              })

              const messageCollect = menu.channel.createMessageCollector({
                filter: messageFilter,
                time: ms("20m"),
                max: 1
              })

              messageCollect.on("collect", async m => {
                const isthumb =
                  m.content.match(
                    /(http[s]*:\/\/)([a-z\-_0-9\/.]+)\.([a-z.]{2,3})\/([a-z0-9\-_\/._~:?#\[\]@!$&'()*+,;=%]*)([a-z0-9]+\.)(jpg|jpeg|png)/i
                  ) != null ||
                  m.attachments.first()?.url ||
                  null
                if (!isthumb) {
                  await select.followUp(
                    "\`🔴\` ・ This is not a image url or an image attachment."
                  )
                  return
                }
footerImage.delete().catch(() => {})
                m.delete().catch(() => {})
                preview
                  .edit({
                    content: preview.content,
                    embeds: [
                      EmbedBuilder.from(preview.embeds[0]).setImage(
                        m.content || m.attachments.first()?.url
                      )
                    ]
                  })
                  .catch(() => {})
              })
            } else if (menu.values[0] === "setTitle") {
              const authorText = await menu.reply({ content: "Send me the embed title.\n> - *Send \`Cancel\` to cancle this operation.*", ephemeral: true , components: []})
                 

              const messageCollect = await menu.channel.createMessageCollector({
                filter: messageFilter,
                time: ms("20m"),
                max: 1
              })
              messageCollect.on("collect", async m => {
            
                const title = m.content
                
            
               

                if (title.toLowerCase() === "cancel") {
                  await authorText.edit({
                    content: `\`🔴\` ・ Successfuly cancelled the operation.`,
                    ephemeral: true
                  })
                } else {
                  await authorText.edit({
                    content: `***🟢 Successfuly set the embed title.***`,
                    ephemeral: true
                  })
m.delete().catch(() => {})
authorText.delete().catch(() => {})
                  preview
                    .edit({
                      content: preview.content,
                      embeds: [
                        EmbedBuilder.from(preview.embeds[0]).setTitle(title)
                      ]
                    })
                    .catch(() => {})
                }

              })
            } else if (menu.values[0] === "setDescription") {
              const authorText = await menu.reply({ content: "Send me the message that will be displayed above the embed\n> - *Send \`Cancel\` to cancle this operation.*", ephemeral: true , components: []})
                 

                  const messageCollect = await menu.channel.createMessageCollector({
                    filter: messageFilter,
                    time: ms("60m"),
                    max: 1
                  })
                  messageCollect.on("collect", async m => {
                
                    const description = m.content
                    
                
                   

                if (description.toLowerCase() === "cancel") {
                  await authorText.edit({
                    content: `\`🔴\` ・ Successfuly cancelled the operation.`,
                    ephemeral: true
                  })
                } else {
                  await authorText.edit({
                    content: `***🟢 Successfuly set the embed description.***`,
                    ephemeral: true
                  })

                  preview
                    .edit({
                      content: preview.content,
                      embeds: [
                        EmbedBuilder.from(preview.embeds[0]).setDescription(
                          description
                        )
                      ]
                    })
                    .catch(() => {})
                    m.delete().catch(() => {})
                    authorText.delete().catch(() => {})
                }
                  })
            } else if (menu.values[0] === "setFooter") {
            
            const row = new ActionRowBuilder().addComponents(
              new ButtonBuilder().setLabel("Set footer").setCustomId("add-footer").setStyle(ButtonStyle.Primary),
            )

            const footerText = await menu.reply({
              content: '***🔐 Click below to set the footer***',
              ephemeral: true,
              components: [
                row
              ]
            })

            const menuCollector = menu.channel.createMessageComponentCollector(
              {
                componentType: ComponentType.Button,
                filter: filter,
                idle: ms("20m")
              }
            )

            menuCollector.on("collect", async btn => {

              if (btn.customId === "add-footer") {
                const fieldName = await btn.reply({ content: "Send me the footer text.", ephemeral: true , components: []})
               

                const messageCollect = await btn.channel.createMessageCollector({
                  filter: messageFilter,
                  time: ms("10m"),
                  max: 1
                })
                messageCollect.on("collect", async m => {
              var fieldN = m.content


                 const fieldValue = await fieldName.edit({ content: "Send me the footer icon\n- *Send \`Cancel\` to have no icon*.", ephemeral: true , components: []})
               
m.delete().catch(() => {})
                const messageCollect = await btn.channel.createMessageCollector({
                  filter: messageFilter,
                  time: ms("10m"),
                  max: 1
                })
                messageCollect.on("collect", async x => {
                  var icon;
                  if(x.content.toLowerCase() === "cancel") {
                     await fieldName.edit({
                      content: `\`🔴\` ・ Not adding an icon.`,
                      ephemeral: true
                    })
                    icon = null;
                  }
                             const isthumb =
                              x.content.match(
                                /(http[s]*:\/\/)([a-z\-_0-9\/.]+)\.([a-z.]{2,3})\/([a-z0-9\-_\/._~:?#\[\]@!$&'()*+,;=%]*)([a-z0-9]+\.)(jpg|jpeg|png)/i
                              ) != null ||
                              x.attachments.first()?.url ||
                              null
                            if (!isthumb && x.content.toLowerCase() !== "cancel")
                              await btn.followUp({
                                content:
                                  "\`🔴\` ・ I'm sorry but your content is not a valid image URL or an image attachment.",
                                ephemeral: true
                              }).then((msg) => {
                                setTimeout(() => {
                                  msg.delete().catch(() => {})
                                }, 2000);
                              })

              
                  
                await fieldName.edit({
                  content: `***🟢 Successfuly added the footer in embed.***`,
                  ephemeral: true
                })

                preview
                  .edit({
                    content: preview.content,
                    embeds: [
                      EmbedBuilder.from(preview.embeds[0]).setFooter({
                        text: fieldN,
                        iconURL:  x.content || x.attachments.first()?.url || null
                      })
                    ]
                  })
                  .catch(() => {})
                  x.delete().catch(() => {})
                  m.delete().catch(() => {})
fieldValue.delete().catch(() => {})
fieldName.delete().catch(() => {})
              footerText.delete().catch(() => {})
            
            })
            })
          
          }
        })
             }
          })
          collector.on("end", async (_collected, reason) => {
            if (reason === "time") {
              const content = new ButtonBuilder()
                .setLabel("Timed Out")
                .setStyle(ButtonStyle.Danger)
                .setCustomId("timeout-embedcreator")
                .setDisabled(true)

              const row = new ActionRowBuilder().addComponents([content])

              await msg.edit({ embeds: [msg.embeds[0]], components: [row] })
            }
          })
        })
    } catch (err) {
      if (options?.strict)
        throw new SimplyError({
          function: "embedCreator",
          title: "An Error occured when running the function ",
          tip: err.stack
        })
      else console.log(`SimplyError - embedCreator | Error: ${err.stack}`)
    }
  })
}
exports.embedCreator = embedCreator;